==> dde-shell_1.99.6.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>GroupNotify</name>
    <message>
        <location filename="../GroupNotify.qml" line="50"/>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <location filename="../NotifyHeader.qml" line="20"/>
        <source>Notification Setting</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
    <message>
        <location filename="../NotifyHeader.qml" line="56"/>
        <source>Notification Center</source>
        <translation>Ilmoituskeskus</translation>
    </message>
    <message>
        <location filename="../NotifyHeader.qml" line="108"/>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Unpin</source>
        <translation>Irrota</translation>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Pin</source>
        <translation>Kiinnitä</translation>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="26"/>
        <source>Notification Setting</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <location filename="../notifyitem.cpp" line="76"/>
        <source>Just now</source>
        <translation>Juuri nyt</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="78"/>
        <source>%1 minutes ago</source>
        <translation>%1 minuuttia sitten</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="80"/>
        <source>%1 hours ago</source>
        <translation>%1 tuntia sitten</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="83"/>
        <source>Yesterday </source>
        <translation>Eilen</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.32.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>GroupNotify</name>
    <message>
        <location filename="../GroupNotify.qml" line="51"/>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <location filename="../NotifyHeader.qml" line="42"/>
        <source>Notification Center</source>
        <translation>Ilmoituskeskus</translation>
    </message>
    <message>
        <location filename="../NotifyHeader.qml" line="90"/>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Unpin</source>
        <translation>Irrota</translation>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Pin</source>
        <translation>Kiinnitä</translation>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="26"/>
        <source>Notification Setting</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <location filename="../notifyitem.cpp" line="78"/>
        <source>Just now</source>
        <translation>Juuri nyt</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="80"/>
        <source>%1 minutes ago</source>
        <translation>%1 min sitten</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="84"/>
        <source>1 hour ago</source>
        <translation>1 h sitten</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="86"/>
        <source>%1 hours ago</source>
        <translation>%1 h sitten</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="90"/>
        <source>Yesterday </source>
        <translation>Eilen</translation>
    </message>
</context>
</TS>
